# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKMathematicalMorphologyPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkGrayscaleErodeImageFilterPython
else:
    import _itkGrayscaleErodeImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkFlatStructuringElementPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.pyBasePython
import itk.itkIndexPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.vnl_matrixPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkBoxImageFilterPython
import itk.itkImageToImageFilterAPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImagePython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageSourceCommonPython
import itk.itkNeighborhoodPython
import itk.itkMathematicalMorphologyEnumsPython

def itkGrayscaleErodeImageFilterIF2IF2SE2_New():
    return itkGrayscaleErodeImageFilterIF2IF2SE2.New()

class itkGrayscaleErodeImageFilterIF2IF2SE2(itk.itkFlatStructuringElementPython.itkKernelImageFilterIF2IF2SE2):
    r"""Proxy of C++ itkGrayscaleErodeImageFilterIF2IF2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleErodeImageFilterIF2IF2SE2_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF2IF2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleErodeImageFilterIF2IF2SE2_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF2IF2SE2_Clone(self)

    def SetBoundary(self, value):
        r"""
        SetBoundary(self, value)

        Parameters
        ----------
        value: float const

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF2IF2SE2_SetBoundary(self, value)

    def GetBoundary(self):
        r"""GetBoundary(self) -> float"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF2IF2SE2_GetBoundary(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF2IF2SE2_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF2IF2SE2_GetAlgorithm(self)
    __swig_destroy__ = _itkGrayscaleErodeImageFilterPython.delete_itkGrayscaleErodeImageFilterIF2IF2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleErodeImageFilterIF2IF2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF2IF2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleErodeImageFilterIF2IF2SE2

        Create a new object of the class itkGrayscaleErodeImageFilterIF2IF2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleErodeImageFilterIF2IF2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleErodeImageFilterIF2IF2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleErodeImageFilterIF2IF2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleErodeImageFilterIF2IF2SE2 in _itkGrayscaleErodeImageFilterPython:
_itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF2IF2SE2_swigregister(itkGrayscaleErodeImageFilterIF2IF2SE2)

def itkGrayscaleErodeImageFilterIF3IF3SE3_New():
    return itkGrayscaleErodeImageFilterIF3IF3SE3.New()

class itkGrayscaleErodeImageFilterIF3IF3SE3(itk.itkFlatStructuringElementPython.itkKernelImageFilterIF3IF3SE3):
    r"""Proxy of C++ itkGrayscaleErodeImageFilterIF3IF3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleErodeImageFilterIF3IF3SE3_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF3IF3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleErodeImageFilterIF3IF3SE3_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF3IF3SE3_Clone(self)

    def SetBoundary(self, value):
        r"""
        SetBoundary(self, value)

        Parameters
        ----------
        value: float const

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF3IF3SE3_SetBoundary(self, value)

    def GetBoundary(self):
        r"""GetBoundary(self) -> float"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF3IF3SE3_GetBoundary(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF3IF3SE3_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF3IF3SE3_GetAlgorithm(self)
    __swig_destroy__ = _itkGrayscaleErodeImageFilterPython.delete_itkGrayscaleErodeImageFilterIF3IF3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleErodeImageFilterIF3IF3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF3IF3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleErodeImageFilterIF3IF3SE3

        Create a new object of the class itkGrayscaleErodeImageFilterIF3IF3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleErodeImageFilterIF3IF3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleErodeImageFilterIF3IF3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleErodeImageFilterIF3IF3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleErodeImageFilterIF3IF3SE3 in _itkGrayscaleErodeImageFilterPython:
_itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIF3IF3SE3_swigregister(itkGrayscaleErodeImageFilterIF3IF3SE3)

def itkGrayscaleErodeImageFilterISS2ISS2SE2_New():
    return itkGrayscaleErodeImageFilterISS2ISS2SE2.New()

class itkGrayscaleErodeImageFilterISS2ISS2SE2(itk.itkFlatStructuringElementPython.itkKernelImageFilterISS2ISS2SE2):
    r"""Proxy of C++ itkGrayscaleErodeImageFilterISS2ISS2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleErodeImageFilterISS2ISS2SE2_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS2ISS2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleErodeImageFilterISS2ISS2SE2_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS2ISS2SE2_Clone(self)

    def SetBoundary(self, value):
        r"""
        SetBoundary(self, value)

        Parameters
        ----------
        value: short const

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS2ISS2SE2_SetBoundary(self, value)

    def GetBoundary(self):
        r"""GetBoundary(self) -> short"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS2ISS2SE2_GetBoundary(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS2ISS2SE2_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS2ISS2SE2_GetAlgorithm(self)
    __swig_destroy__ = _itkGrayscaleErodeImageFilterPython.delete_itkGrayscaleErodeImageFilterISS2ISS2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleErodeImageFilterISS2ISS2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS2ISS2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleErodeImageFilterISS2ISS2SE2

        Create a new object of the class itkGrayscaleErodeImageFilterISS2ISS2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleErodeImageFilterISS2ISS2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleErodeImageFilterISS2ISS2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleErodeImageFilterISS2ISS2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleErodeImageFilterISS2ISS2SE2 in _itkGrayscaleErodeImageFilterPython:
_itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS2ISS2SE2_swigregister(itkGrayscaleErodeImageFilterISS2ISS2SE2)

def itkGrayscaleErodeImageFilterISS3ISS3SE3_New():
    return itkGrayscaleErodeImageFilterISS3ISS3SE3.New()

class itkGrayscaleErodeImageFilterISS3ISS3SE3(itk.itkFlatStructuringElementPython.itkKernelImageFilterISS3ISS3SE3):
    r"""Proxy of C++ itkGrayscaleErodeImageFilterISS3ISS3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleErodeImageFilterISS3ISS3SE3_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS3ISS3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleErodeImageFilterISS3ISS3SE3_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS3ISS3SE3_Clone(self)

    def SetBoundary(self, value):
        r"""
        SetBoundary(self, value)

        Parameters
        ----------
        value: short const

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS3ISS3SE3_SetBoundary(self, value)

    def GetBoundary(self):
        r"""GetBoundary(self) -> short"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS3ISS3SE3_GetBoundary(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS3ISS3SE3_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS3ISS3SE3_GetAlgorithm(self)
    __swig_destroy__ = _itkGrayscaleErodeImageFilterPython.delete_itkGrayscaleErodeImageFilterISS3ISS3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleErodeImageFilterISS3ISS3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS3ISS3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleErodeImageFilterISS3ISS3SE3

        Create a new object of the class itkGrayscaleErodeImageFilterISS3ISS3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleErodeImageFilterISS3ISS3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleErodeImageFilterISS3ISS3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleErodeImageFilterISS3ISS3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleErodeImageFilterISS3ISS3SE3 in _itkGrayscaleErodeImageFilterPython:
_itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterISS3ISS3SE3_swigregister(itkGrayscaleErodeImageFilterISS3ISS3SE3)

def itkGrayscaleErodeImageFilterIUC2IUC2SE2_New():
    return itkGrayscaleErodeImageFilterIUC2IUC2SE2.New()

class itkGrayscaleErodeImageFilterIUC2IUC2SE2(itk.itkFlatStructuringElementPython.itkKernelImageFilterIUC2IUC2SE2):
    r"""Proxy of C++ itkGrayscaleErodeImageFilterIUC2IUC2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleErodeImageFilterIUC2IUC2SE2_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC2IUC2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleErodeImageFilterIUC2IUC2SE2_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC2IUC2SE2_Clone(self)

    def SetBoundary(self, value):
        r"""
        SetBoundary(self, value)

        Parameters
        ----------
        value: unsigned char const

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC2IUC2SE2_SetBoundary(self, value)

    def GetBoundary(self):
        r"""GetBoundary(self) -> unsigned char"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC2IUC2SE2_GetBoundary(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC2IUC2SE2_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC2IUC2SE2_GetAlgorithm(self)
    __swig_destroy__ = _itkGrayscaleErodeImageFilterPython.delete_itkGrayscaleErodeImageFilterIUC2IUC2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleErodeImageFilterIUC2IUC2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC2IUC2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleErodeImageFilterIUC2IUC2SE2

        Create a new object of the class itkGrayscaleErodeImageFilterIUC2IUC2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleErodeImageFilterIUC2IUC2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleErodeImageFilterIUC2IUC2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleErodeImageFilterIUC2IUC2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleErodeImageFilterIUC2IUC2SE2 in _itkGrayscaleErodeImageFilterPython:
_itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC2IUC2SE2_swigregister(itkGrayscaleErodeImageFilterIUC2IUC2SE2)

def itkGrayscaleErodeImageFilterIUC3IUC3SE3_New():
    return itkGrayscaleErodeImageFilterIUC3IUC3SE3.New()

class itkGrayscaleErodeImageFilterIUC3IUC3SE3(itk.itkFlatStructuringElementPython.itkKernelImageFilterIUC3IUC3SE3):
    r"""Proxy of C++ itkGrayscaleErodeImageFilterIUC3IUC3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleErodeImageFilterIUC3IUC3SE3_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC3IUC3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleErodeImageFilterIUC3IUC3SE3_Pointer"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC3IUC3SE3_Clone(self)

    def SetBoundary(self, value):
        r"""
        SetBoundary(self, value)

        Parameters
        ----------
        value: unsigned char const

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC3IUC3SE3_SetBoundary(self, value)

    def GetBoundary(self):
        r"""GetBoundary(self) -> unsigned char"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC3IUC3SE3_GetBoundary(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC3IUC3SE3_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC3IUC3SE3_GetAlgorithm(self)
    __swig_destroy__ = _itkGrayscaleErodeImageFilterPython.delete_itkGrayscaleErodeImageFilterIUC3IUC3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleErodeImageFilterIUC3IUC3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC3IUC3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleErodeImageFilterIUC3IUC3SE3

        Create a new object of the class itkGrayscaleErodeImageFilterIUC3IUC3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleErodeImageFilterIUC3IUC3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleErodeImageFilterIUC3IUC3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleErodeImageFilterIUC3IUC3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleErodeImageFilterIUC3IUC3SE3 in _itkGrayscaleErodeImageFilterPython:
_itkGrayscaleErodeImageFilterPython.itkGrayscaleErodeImageFilterIUC3IUC3SE3_swigregister(itkGrayscaleErodeImageFilterIUC3IUC3SE3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def grayscale_erode_image_filter(*args: itkt.ImageLike,  kernel: Union[itkt.FlatStructuringElement, itkt.FlatStructuringElement]=..., boundary: float=..., algorithm=..., radius: Union[int, Sequence[int], Sequence[int], int]=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for GrayscaleErodeImageFilter"""
    import itk

    kwarg_typehints = { 'kernel':kernel,'boundary':boundary,'algorithm':algorithm,'radius':radius }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.GrayscaleErodeImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def grayscale_erode_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKMathematicalMorphology.GrayscaleErodeImageFilter
    grayscale_erode_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    grayscale_erode_image_filter.__doc__ = filter_object.__doc__



